@@ -7,6 +7,10 @@ use std::{
     path::Path,
     ptr, slice,
 };
+#[cfg(feature = "deps")]
+pub mod deps {
+    pub use nstd_collections;
+}
 pub const NSTD_STD_FS_CREATE: usize = 0b00000001;
 pub const NSTD_STD_FS_READ: usize = 0b00000010;
 pub const NSTD_STD_FS_WRITE: usize = 0b00000100;
@@ -80,7 +84,7 @@ pub unsafe extern "C" fn nstd_std_fs_dir_contents(dir: *const c_char) -> NSTDVec
 pub unsafe extern "C" fn nstd_std_fs_dir_contents_free(contents: &mut NSTDVec) -> c_int {
     for i in 0..contents.size {
         let element = nstd_std_collections_vec_get(contents, i) as *mut *mut c_char;
-        CString::from_raw(*element);
+        drop(CString::from_raw(*element));
     }
     nstd_std_collections_vec_free(contents)
 }
@@ -200,7 +204,7 @@ pub unsafe extern "C" fn nstd_std_fs_read(file: NSTDFile) -> *mut c_char {
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_std_fs_free_read(contents: *mut *mut c_char) {
-    CString::from_raw(*contents);
+    drop(CString::from_raw(*contents));
     *contents = ptr::null_mut();
 }
 
